@@ -1,5 +1,5 @@
 #
-# $Id: Split.pm,v 0.35 2004/01/02 02:27:13 st.schubiger Exp $
+# $Id: Split.pm,v 0.36 2004/01/02 23:43:01 st.schubiger Exp $
 
 package Dir::Split;
 
@@ -12,24 +12,24 @@ use File::Copy 'cp';
 use File::Path;
 use File::Spec;
 
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 
 our (# external refs
         $Source_dir_ref, # scl
         $Target_dir_ref, # scl
 
      # opt refs
-        $Mode_ref,     # scl
-        $Override_ref, # scl
-        $Warn_ref,     # scl
-        $Verbose_ref,  # scl
-        $Ident_ref,    # scl
-        $F_limit_ref,  # scl
-        $F_sort_ref,   # scl
-        $Cont_num_ref, # scl
-        $Sep_ref,      # scl
-        $L_req_ref,    # scl
-        $Case_ref,     # scl
+        $Mode_ref,       # scl
+        $Override_ref,   # scl
+        $Warn_ref,       # scl
+        $Verbose_ref,    # scl
+        $Ident_ref,      # scl
+        $F_limit_ref,    # scl
+        $F_sort_ref,     # scl
+        $Num_contin_ref, # scl
+        $Sep_ref,        # scl
+        $L_req_ref,      # scl
+        $Case_ref,       # scl
 
      # data refs
         $Files_ref,        # arr
@@ -46,22 +46,10 @@ our (# external refs
         $Path,
         $Ret_f_moved,
         $Suffix,
-    );
 
-{
-    my %Presets = (
-                    warn =>  {  dir  =>    "exists (d)\t",
-                                file =>    "exists (f)\t",
-                    },
-    );
-
-    {
-    no strict 'refs';
-
-    ${__PACKAGE__.'::Warn'}{'dir'} ||= $Presets{'warn'}{'dir'};
-    ${__PACKAGE__.'::Warn'}{'file'} ||= $Presets{'warn'}{'file'};
-    }
-}
+     # constants
+        $PACKAGE,
+);
 
 =head1 NAME
 
@@ -84,8 +72,8 @@ Dir::Split - Split the files of a directory to subdirectories.
                               file_sort      =>         '+',
                 },
 
-                suffix  => {  continue_num   =>         'y',
-                              separator      =>         '-',
+                suffix  => {  separator      =>         '-',
+                              continue       =>         'y',
                               length         =>           5,
                 },
  );
@@ -100,12 +88,6 @@ Dir::Split - Split the files of a directory to subdirectories.
  # split files to subdirs
  $files_moved = $dir->split (\$source_dir, \$target_dir);
 
- # change the subdir identifier
- $dir->{'sub_dir'}{'identifier'} = 'test';
-
- # split files to subdirs
- $files_moved = $dir->split (\$source_dir, \$target_dir);
-
 =head1 DESCRIPTION
 
 C<Dir::Split> moves files from a source directory to numbered subdirectories within
@@ -131,14 +113,13 @@ sub new {
     my $class = ref ($pkg) || $pkg;
     my $obj = Dir::Split::_tie_var($Opt_ref);
 
-    bless $obj, $class;
+    return bless $obj, $class;
 }
 
 #
 # _tie_var (\%hash)
 #
-# Dereferences a two-dimensional hash. A reference
-# to a private hash will be returned.
+# Dereferences a two-dimensional hash.
 #
 
 sub _tie_var {
@@ -154,7 +135,7 @@ sub _tie_var {
         else { $my_hash{$key} = $$Opt_ref{$key} }
     }
 
-    \%my_hash;
+    return \%my_hash;
 };
 
 =head2 split ( \$source_dir, \$target_dir )
@@ -178,6 +159,28 @@ sub split {
     croak q~usage: $obj->split (\$source_dir, \$target_dir)~
       unless ref $Source_dir_ref eq 'SCALAR' && ref $Target_dir_ref eq 'SCALAR';
 
+    $self->_init_refs();
+    $self->_sanity_input();
+    $self->_init_presets();
+
+    $self->_gather_files();
+    my $sub_suffix = "_suffix_$$Mode_ref";
+    $self->$sub_suffix();
+    $self->_move();
+
+    # amount of files that have been moved
+    return $$Ret_f_moved_ref ? $$Ret_f_moved_ref : undef;
+}
+
+#
+# _init_refs()
+#
+# Initializes references.
+#
+
+sub _init_refs {
+    my $self = $_[0];
+
     # opts refs
     $Mode_ref = \$self->{'mode'};
     $Verbose_ref = \$self->{'options'}{'verbose'};
@@ -186,7 +189,7 @@ sub split {
     $Ident_ref = \$self->{'sub_dir'}{'identifier'};
     $F_limit_ref = \$self->{'sub_dir'}{'file_limit'};
     $F_sort_ref = \$self->{'sub_dir'}{'file_sort'};
-    $Cont_num_ref = \$self->{'suffix'}{'continue_num'};
+    $Num_contin_ref = \$self->{'suffix'}{'continue'};
     $Sep_ref = \$self->{'suffix'}{'separator'};
     $L_req_ref = \$self->{'suffix'}{'length'};
     $Case_ref = \$self->{'suffix'}{'case'};
@@ -197,19 +200,12 @@ sub split {
     $F_names_char_ref = \%F_names_char;
     $Path_ref = \$Path;
     $Suffix_ref = \$Suffix;
-
-    $self->_sanity_input;
-    $self->_gather_files;
-    my $sub_suffix = "_suffix_$$Mode_ref";
-    $self->$sub_suffix;
-    $self->_move;
 }
 
 #
 # _sanity_input()
 #
-# Ensures that the interface input passes sanity;
-# if not, croak.
+# Ensures that options input passes sanity.
 #
 
 sub _sanity_input {
@@ -224,7 +220,7 @@ sub _sanity_input {
                     case        =>    'No suffix case mode specified.',
                     file_limit  =>    'No file limit specified.',
                     file_sort   =>    'No file sort mode specified.',
-                    cont_num    =>    'No continuation mode specified.',
+                    continue    =>    'No continuation mode specified.',
                     length      =>    'No suffix length specified.'
     );
 
@@ -267,8 +263,8 @@ sub _sanity_input {
             unless ($$F_sort_ref eq '+' || $$F_sort_ref eq '-') {
                 $err_input = $err_msg{'file_sort'}; last;
             }
-            unless ($$Cont_num_ref eq 'y' || $$Cont_num_ref eq 'n') {
-                $err_input = $err_msg{'cont_num'}; last;
+            unless ($$Num_contin_ref eq 'y' || $$Num_contin_ref eq 'n') {
+                $err_input = $err_msg{'continue'}; last;
             }
             unless ($$L_req_ref =~ /\d/) {
                 $err_input = $err_msg{'length'}; last;
@@ -279,11 +275,30 @@ sub _sanity_input {
     croak $err_input if $err_input;
 }
 
+#
+# _init_presets()
+#
+# Initializes var presets.
+#
+
+sub _init_presets {
+    my %Presets = (
+                    warn =>  {  dir  =>    "exists (d)\t",
+                                file =>    "exists (f)\t",
+                    },
+    );
+
+    no strict 'refs';
+    $PACKAGE = __PACKAGE__.'::';
+
+    ${$PACKAGE.'warn'}{'dir'} ||= $Presets{'warn'}{'dir'};
+    ${$PACKAGE.'warn'}{'file'} ||= $Presets{'warn'}{'file'};
+}
+
 #
 # _gather_files()
 #
-# Gathers the files the source directory
-# consists of and sorts them if required.
+# Gathers the files from the source directory.
 #
 
 sub _gather_files {
@@ -292,13 +307,84 @@ sub _gather_files {
     $self->_dir_read($Source_dir_ref, $Files_ref);
     @$Files_ref = grep !-d File::Spec->catfile($$Source_dir_ref, $_), @$Files_ref;
 
-    if ($$Mode_ref eq 'num' && ($$F_sort_ref eq '+' || $$F_sort_ref eq '-') ) {
-        # preserve case-sensitive filenames in hash.
-        foreach (@$Files_ref) { $$F_names_case_ref{lc($_)} = $_ }
-        @$Files_ref = map { lc } @$Files_ref;
+    # if numeric splitting, sort the files.
+    if ($$Mode_ref eq 'num' && ($$F_sort_ref eq '+' || $$F_sort_ref eq '-')) {
+        $self->_sort_files();
+    }
+}
 
-        if ($$F_sort_ref eq '+') { @$Files_ref = sort @$Files_ref }
-        elsif ($$F_sort_ref eq '-') { @$Files_ref = reverse @$Files_ref }
+#
+# _sort_files()
+#
+# Sorts the files if numeric splitting.
+#
+
+sub _sort_files {
+    # preserve case-sensitive filenames.
+    foreach (@$Files_ref) {
+        $$F_names_case_ref{lc($_)} = $_;
+    }
+    @$Files_ref = map { lc } @$Files_ref;
+
+    if ($$F_sort_ref eq '+') { @$Files_ref = sort @$Files_ref }
+    elsif ($$F_sort_ref eq '-') { @$Files_ref = reverse @$Files_ref }
+}
+
+#
+# _suffix_num()
+#
+# Sub handler for numeric suffixes.
+#
+
+sub _suffix_num {
+    my $self = $_[0];
+
+    if ($$Num_contin_ref eq 'y') { $self->_suffix_num_contin() }
+
+    $self->_suffix_num_sum_up();
+}
+
+#
+# _suffix_num_contin()
+#
+# Evaluates the highest existing subdir suffix number
+# from the target directory.
+#
+
+sub _suffix_num_contin {
+    my $self = $_[0];
+
+    my @dirs;
+    $self->_dir_read($Target_dir_ref, \@dirs);
+    @dirs = grep -d File::Spec->catfile($$Target_dir_ref, $_), @dirs;
+
+    # surpress warnings
+    $$Suffix_ref = 0;
+
+    my $sep = quotemeta $$Sep_ref;
+    foreach (@dirs) {
+        # extract exist. identifier
+        ($_) = /(.+?)$sep(.*)/;
+        # increase suffix to highest number
+        if ($$Ident_ref eq $_ && $2 !~ /[a-z]/i) {
+            $$Suffix_ref = $2 if $2 > $$Suffix_ref;
+        }
+    }
+}
+
+#
+# _suffix_num_sum_up()
+#
+# Sums the numeric suffix with zeros up if required.
+#
+
+sub _suffix_num_sum_up {
+    # initialize suffix or avoid suffix collision if != 0
+    $$Suffix_ref++;
+
+    if (length $$Suffix_ref != $$L_req_ref) {
+        my $format = "%0.$$L_req_ref" . 'd';
+        $$Suffix_ref = sprintf $format, $$Suffix_ref;
     }
 }
 
@@ -322,51 +408,10 @@ sub _suffix_char {
     undef @$Files_ref;
 }
 
-#
-# _suffix_num()
-#
-# Evaluates the highest existing subdir suffix number
-# from the target directory in order to continue numbering
-# where it stopped previously. The suffix will be summed up
-# with zeros if required.
-#
-
-sub _suffix_num {
-    my $self = $_[0];
-
-    # surpress warnings
-    $$Suffix_ref = 0;
-
-    if ($$Cont_num_ref eq 'y') {
-        my @dirs;
-        $self->_dir_read($Target_dir_ref, \@dirs);
-        @dirs = grep -d File::Spec->catfile($$Target_dir_ref, $_), @dirs;
-
-        my $sep = quotemeta $$Sep_ref;
-        foreach (@dirs) {
-            # extract exist. identifier
-            ($_) = /(.+?)$sep(.*)/;
-            # increase suffix to highest number
-            if ($$Ident_ref eq $_ && $2 !~ /[a-z]/i) {
-               $$Suffix_ref = $2 if $2 > $$Suffix_ref;
-            }
-        }
-    }
-
-    # Initialize suffix or avoid suffix collision if != 0
-    $$Suffix_ref++;
-
-    if (length $$Suffix_ref != $$L_req_ref) {
-        my $format = "%0.$$L_req_ref" . 'd';
-        $$Suffix_ref = sprintf $format, $$Suffix_ref;
-    }
-}
-
 #
 # _move()
 #
-# Invokes either _move_num() or _move_char() by
-# relying upon the opts.
+# Sub handler for moving files.
 #
 
 sub _move {
@@ -377,8 +422,6 @@ sub _move {
     # sub handler
     my $sub_move = "_move_$$Mode_ref";
     $self->$sub_move;
-
-    $$Ret_f_moved_ref ? $$Ret_f_moved_ref : undef;
 }
 
 #
@@ -403,9 +446,7 @@ sub _move_num {
 #
 # _move_char()
 #
-# Basically the same operation as _move_num(),
-# except that characteristic suffixes are attached
-# to the subdirs.
+# Moves the files to characteristic subdirs.
 #
 
 sub _move_char {
@@ -423,8 +464,7 @@ sub _move_char {
 #
 # _dir_read (\$dir, \@items)
 #
-# Stores the items a directory consists of
-# in a referenced array.
+# Reads the files of a directory.
 #
 
 sub _dir_read {
@@ -437,7 +477,7 @@ sub _dir_read {
 }
 
 #
-# _mkpath ($Suffix)
+# _mkpath ($suffix)
 #
 # Creates subdirs.
 # Upon dir collision optional warning
@@ -445,15 +485,12 @@ sub _dir_read {
 #
 
 sub _mkpath {
-    shift; my $suffix = $_[0];
+    my ($self, $suffix) = @_;
 
     $$Path_ref = File::Spec->catfile($$Target_dir_ref, "$$Ident_ref$$Sep_ref$suffix");
 
-    if (-e $$Path_ref) {
-        warn "$Dir::Split::Warn{'dir'} $$Path_ref\n"
-          if $$Warn_ref eq 'all' || $$Warn_ref eq 'dir';
-        return unless $$Override_ref eq 'all' || $$Override_ref eq 'dir';
-    }
+    return if $self->_exists_and_not_override('dir', $$Path_ref);
+
     mkpath $$Path_ref, $$Verbose_ref
       or croak qq~Could not create subdir $$Path_ref: $!~;
 }
@@ -461,21 +498,19 @@ sub _mkpath {
 #
 # _cp_unlink ($file)
 #
-# Copies files and unlinks them after they've been copied.
-# Upon file collision optional warning and overriding avoidance.
+# Copies files and unlinks them.
+# Upon file collision optional warning
+# and overriding avoidance.
 #
 
 sub _cp_unlink {
-    shift; my $file = $_[0];
+    my ($self, $file) = @_;
 
     my $path_full = File::Spec->catfile($$Path_ref, $file);
     $file = File::Spec->catfile($$Source_dir_ref, $file);
 
-    if (-e $path_full) {
-        warn "$Dir::Split::Warn{'file'} $path_full \n"
-          if $$Warn_ref eq 'all' || $$Warn_ref eq 'file';
-        return unless $$Override_ref eq 'all' || $$Override_ref eq 'file';
-    }
+    return if $self->_exists_and_not_override('file', $path_full);
+
     cp $file, $path_full or
       croak qq~Could not copy file $file to subdir $path_full: $!~;
     unlink $file or croak qq~Could not remove file $file: $!~;
@@ -483,12 +518,33 @@ sub _cp_unlink {
     $$Ret_f_moved_ref++;
 }
 
+#
+# _exists_and_not_override ($item, $path)
+#
+# Check for existing files/paths and warn accordingly.
+#
+
+sub _exists_and_not_override {
+    shift; my ($item, $path) = @_;
+
+    if (-e $path) {
+        if ($$Warn_ref eq 'all' || $$Warn_ref eq $item) {
+            no strict 'refs';
+            warn "${$PACKAGE.'warn'}{$item} $path\n";
+        }
+
+        return 1 unless $$Override_ref eq 'all' || $$Override_ref eq $item;
+    }
+
+    return 0;
+}
+
 1;
 __END__
 
 =head1 OPTIONS
 
-=head2 numeric splitting
+=head2 numeric
 
 Split files to subdirectories with a numeric suffix. Numbering may
 be continued or started at 1 one each time. Options are explained below.
@@ -507,12 +563,86 @@ See EXAMPLES to gain an understanding how numeric splitting works.
                    },
 
                    suffix  => {  separator      =>         '-',
-                                 continue_num   =>         'y',
+                                 continue       =>         'y',
                                  length         =>           5,
                    },
     );
 
-=head2 characteristic splitting
+=over 4
+
+=item B<mode>
+
+string - either I<num> for numeric or I<char> for characteristic.
+
+=item B<options/verbose>
+
+integer - verbosity; if enabled, mkpath will output the pathes
+on creating subdirectories.
+
+ MODES
+   0  disabled
+   1  enabled
+
+=item B<options/warn>
+
+string - warn upon the encounter of existing files/dirs.
+
+ LEVELS
+   none
+   file
+   dir
+   all
+
+=item B<options/override>
+
+string - override of existing files/dirs.
+
+ LEVELS
+   none
+   file
+   dir
+   all
+
+=item B<sub_dir/identifier>
+
+string - prefix of each subdirectory created.
+
+=item B<sub_dir/file_limit>
+
+integer - limit of files per subdirectory.
+
+=item B<sub_dir/file_sort>
+
+string - sort order of files.
+
+ MODES
+   +  ascending
+   -  descending
+
+=item B<suffix/separator>
+
+string - separates the identifier from the suffix.
+
+=item B<suffix/continue>
+
+string - numbering continuation (will start at 1 if no).
+
+ MODES
+   y  yes
+   n  no
+
+=item B<suffix/length>
+
+integer - amount of zeros to be added to the suffix.
+
+Differing identifiers or separators do affect the numbering e.g. I<systm-> does
+not equal I<system->, I<system_> does not equal I<system->. B<file_limit>, B<file_sort>
+and B<length> options have no influence on decisions whether the numbering shall
+be continued, whereas B<identifier>, B<separator> and B<continue> do.
+
+=back
+
+=head2 characteristic
 
 Split files to subdirectories with a characteristic suffix. Files
 are assigned to subdirectories which suffixes correspond with the leading character
@@ -537,15 +667,11 @@ how characteristic splitting works.
 
 =over 4
 
-=item generic behavior
-
-=over 4
-
-=item C<mode>
+=item B<mode>
 
 string - either I<num> for numeric or I<char> for characteristic.
 
-=item C<options/verbose>
+=item B<options/verbose>
 
 integer - verbosity; if enabled, mkpath will output the pathes
 on creating subdirectories.
@@ -554,7 +680,7 @@ on creating subdirectories.
    0  disabled
    1  enabled
 
-=item C<options/warn>
+=item B<options/warn>
 
 string - warn upon the encounter of existing files/dirs.
 
@@ -564,7 +690,7 @@ string - warn upon the encounter of existing files/dirs.
    dir
    all
 
-=item C<options/override>
+=item B<options/override>
 
 string - override of existing files/dirs.
 
@@ -574,56 +700,15 @@ string - override of existing files/dirs.
    dir
    all
 
-=item C<sub_dir/identifier>
+=item B<sub_dir/identifier>
 
 string - prefix of each subdirectory created.
 
-=item C<suffix/separator>
+=item B<suffix/separator>
 
 string - separates the identifier from the suffix.
 
-=back
-
-=item numeric behavior
-
-=over 4
-
-=item C<sub_dir/file_limit>
-
-integer - limit of files per subdirectory.
-
-=item C<sub_dir/file_sort>
-
-string - sort order of files.
-
- MODES
-   +  ascending
-   -  descending
-
-=item C<suffix/continue_num>
-
-string - numbering continuation (will start at 1 if no).
-
- MODES
-   y  yes
-   n  no
-
-=item C<suffix/length>
-
-integer - amount of zeros to be added to the suffix.
-
-=back
-
-Differing identifiers or separators do affect the numbering e.g. I<systm-> does
-not equal I<system->, I<system_> does not equal I<system->. C<file_limit>, C<file_sort>
-and C<length> options have no influence on decisions whether the numbering shall
-be continued, whereas C<identifier>, C<separator> and C<continue_num> do.
-
-=item characteristic behavior
-
-=over 4
-
-=item C<suffix/case>
+=item B<suffix/case>
 
 string - lower/upper case of the suffix.
 
@@ -633,13 +718,11 @@ string - lower/upper case of the suffix.
 
 =back
 
-=back
-
 =head2 presets
 
 The warning messages upon the encounter of existing files/dirs.
 
-    %Dir::Split::Warn = (  dir  =>    "exists (d)\t",
+    %Dir::Split::warn = (  dir  =>    "exists (d)\t",
                            file =>    "exists (f)\t",
     );
 
@@ -689,7 +772,7 @@ C<Perl 5.6.1>; C<File::Copy>, C<File::Path>, C<File::Spec>.
 Recursive source directory processing is not supported;
 existing directories within the source directory will be ignored.
 
-Minus integer values in C<file_limit> and C<length> options
+Minus integer values in B<file_limit> and B<length> options
 cause an odd behavior at runtime.
 
 =head1 SEE ALSO
